@@ -11,9 +11,9 @@
 
 #include <KEmailAddress>
 #include <KLocalizedString>
-#include <QVBoxLayout>
 #include <QDialogButtonBox>
 #include <QPushButton>
+#include <QVBoxLayout>
 
 using namespace IncidenceEditorNG;
 
@@ -23,9 +23,8 @@ AlarmDialog::AlarmDialog(KCalendarCore::Incidence::IncidenceType incidenceType,
     , mIncidenceType(incidenceType)
 {
     setWindowTitle(i18nc("@title:window", "Create a new reminder"));
-    auto *mainLayout = new QVBoxLayout(this);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(
-        QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto mainLayout = new QVBoxLayout(this);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -90,10 +89,10 @@ void AlarmDialog::load(const KCalendarCore::Alarm::Ptr &alarm)
     offset = offset / 60; // make minutes
     int useoffset = offset;
 
-    if (offset % (24 * 60) == 0 && offset > 0) {     // divides evenly into days?
+    if (offset % (24 * 60) == 0 && offset > 0) { // divides evenly into days?
         useoffset = offset / (24 * 60);
         mUi->mOffsetUnit->setCurrentIndex(2);
-    } else if (offset % 60 == 0 && offset > 0) {   // divides evenly into hours?
+    } else if (offset % 60 == 0 && offset > 0) { // divides evenly into hours?
         useoffset = offset / 60;
         mUi->mOffsetUnit->setCurrentIndex(1);
     } else {
@@ -106,7 +105,7 @@ void AlarmDialog::load(const KCalendarCore::Alarm::Ptr &alarm)
     mUi->mRepeats->setChecked(alarm->repeatCount() > 0);
     if (alarm->repeatCount() > 0) {
         mUi->mRepeatCount->setValue(alarm->repeatCount());
-        mUi->mRepeatInterval->setValue(alarm->snoozeTime().asSeconds() / 60);   // show as minutes
+        mUi->mRepeatInterval->setValue(alarm->snoozeTime().asSeconds() / 60); // show as minutes
     }
     int id = 0;
 
@@ -122,15 +121,13 @@ void AlarmDialog::load(const KCalendarCore::Alarm::Ptr &alarm)
         mUi->mAppArguments->setText(alarm->programArguments());
         id = 2;
         break;
-    case KCalendarCore::Alarm::Email:
-    {
+    case KCalendarCore::Alarm::Email: {
         mUi->mTypeCombo->setCurrentIndex(3);
         KCalendarCore::Person::List addresses = alarm->mailAddresses();
         QStringList add;
         add.reserve(addresses.count());
         const KCalendarCore::Person::List::ConstIterator end(addresses.constEnd());
-        for (KCalendarCore::Person::List::ConstIterator it = addresses.constBegin();
-             it != end; ++it) {
+        for (KCalendarCore::Person::List::ConstIterator it = addresses.constBegin(); it != end; ++it) {
             add << (*it).fullName();
         }
         mUi->mEmailAddress->setText(add.join(QLatin1String(", ")));
@@ -147,8 +144,7 @@ void AlarmDialog::load(const KCalendarCore::Alarm::Ptr &alarm)
     }
 
     mUi->mTypeStack->setCurrentIndex(id);
-    if (alarm->audioFile().isEmpty()
-        && IncidenceEditorNG::EditorConfig::instance()->defaultAudioFileReminders()) {
+    if (alarm->audioFile().isEmpty() && IncidenceEditorNG::EditorConfig::instance()->defaultAudioFileReminders()) {
         mUi->mSoundFile->setUrl(IncidenceEditorNG::EditorConfig::instance()->audioFilePath());
     }
 }
@@ -169,7 +165,7 @@ void AlarmDialog::save(const KCalendarCore::Alarm::Ptr &alarm) const
     }
 
     const int beforeafterpos = mUi->mBeforeAfter->currentIndex();
-    if (beforeafterpos % 2 == 0) {   // before -> negative
+    if (beforeafterpos % 2 == 0) { // before -> negative
         offset = -offset;
     }
 
@@ -181,28 +177,27 @@ void AlarmDialog::save(const KCalendarCore::Alarm::Ptr &alarm) const
 
     // We assume that if mAllowBeginReminders is not set, that mAllowBeginReminders
     // is set.
-    if (!mAllowBeginReminders) {   // before or after DTDUE
+    if (!mAllowBeginReminders) { // before or after DTDUE
         alarm->setEndOffset(KCalendarCore::Duration(offset));
-    } else if (beforeafterpos == 0 || beforeafterpos == 1) {   // before or after DTSTART
+    } else if (beforeafterpos == 0 || beforeafterpos == 1) { // before or after DTSTART
         alarm->setStartOffset(KCalendarCore::Duration(offset));
-    } else if (beforeafterpos == 2 || beforeafterpos == 3) {  // before or after DTEND/DTDUE
+    } else if (beforeafterpos == 2 || beforeafterpos == 3) { // before or after DTEND/DTDUE
         alarm->setEndOffset(KCalendarCore::Duration(offset));
     }
 
     // Repeating
     if (mUi->mRepeats->isChecked()) {
         alarm->setRepeatCount(mUi->mRepeatCount->value());
-        alarm->setSnoozeTime(mUi->mRepeatInterval->value() * 60);   // convert back to seconds
+        alarm->setSnoozeTime(mUi->mRepeatInterval->value() * 60); // convert back to seconds
     } else {
         alarm->setRepeatCount(0);
     }
 
-    if (mUi->mTypeCombo->currentIndex() == 1) {   // Audio
+    if (mUi->mTypeCombo->currentIndex() == 1) { // Audio
         alarm->setAudioAlarm(mUi->mSoundFile->url().toLocalFile());
-    } else if (mUi->mTypeCombo->currentIndex() == 2) {   // Application / script
-        alarm->setProcedureAlarm(mUi->mApplication->url().toLocalFile(),
-                                 mUi->mAppArguments->text());
-    } else if (mUi->mTypeCombo->currentIndex() == 3) {   // Email
+    } else if (mUi->mTypeCombo->currentIndex() == 2) { // Application / script
+        alarm->setProcedureAlarm(mUi->mApplication->url().toLocalFile(), mUi->mAppArguments->text());
+    } else if (mUi->mTypeCombo->currentIndex() == 3) { // Email
         QStringList addresses = KEmailAddress::splitAddressList(mUi->mEmailAddress->text());
         KCalendarCore::Person::List add;
         add.reserve(addresses.count());
