@@ -12,27 +12,20 @@
 
 #include <QDialog>
 
-namespace Ui {
+namespace Ui
+{
 class AlarmDialog;
 }
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 class AlarmDialog : public QDialog
 {
     Q_OBJECT
 public:
-    enum Unit {
-        Minutes,
-        Hours,
-        Days
-    };
+    enum Unit { Minutes, Hours, Days };
 
-    enum When {
-        BeforeStart = 0,
-        AfterStart,
-        BeforeEnd,
-        AfterEnd
-    };
+    enum When { BeforeStart = 0, AfterStart, BeforeEnd, AfterEnd };
 
 public:
     /**
@@ -40,7 +33,7 @@ public:
       @p incidenceType will influence i18n strings, that will be different for to-dos.
      */
     explicit AlarmDialog(KCalendarCore::Incidence::IncidenceType incidenceType, QWidget *parent = nullptr);
-    ~AlarmDialog();
+    ~AlarmDialog() override;
     void load(const KCalendarCore::Alarm::Ptr &alarm);
     void save(const KCalendarCore::Alarm::Ptr &alarm) const;
     void setAllowBeginReminders(bool allow);
