@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (C) 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef INCIDENCEEDITOR_EDITORITEMMANAGER_H
@@ -25,22 +12,23 @@
 #include <Collection>
 #include <QObject>
 
-namespace Akonadi {
+namespace Akonadi
+{
 class Collection;
 class Item;
-class ItemFetchScope;
 }
 
 class KJob;
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 class ItemEditorUi;
 class ItemEditorPrivate;
 
 /**
  * Helper class for creating dialogs that let the user create and edit the payload
- * of Akonadi items (e.g. events, contacts, etc). This class supports editting of
- * one item at a time and hanldes all Akonadi specific logic like Item creation,
+ * of Akonadi items (e.g. events, contacts, etc). This class supports editing of
+ * one item at a time and handles all Akonadi specific logic like Item creation,
  * Item modifying and monitoring of changes to the item during editing.
  */
 // template <typename PayloadT>
@@ -53,23 +41,23 @@ public:
      * Receives an option IncidenceChanger, so you can share the undo/redo stack with your
      * application.
      */
-    EditorItemManager(ItemEditorUi *ui, Akonadi::IncidenceChanger *changer = nullptr);
+    explicit EditorItemManager(ItemEditorUi *ui, Akonadi::IncidenceChanger *changer = nullptr);
 
     /**
      * Destructs the ItemEditor. Unsaved changes will get lost at this point.
      */
-    ~EditorItemManager();
+    ~EditorItemManager() override;
 
     enum ItemState {
-        AfterSave,  /**< Returns the last saved item */
-        BeforeSave  /**< Returns an item with the original payload before the last save call */
+        AfterSave, /**< Returns the last saved item */
+        BeforeSave /**< Returns an item with the original payload before the last save call */
     };
 
     /**
      * Returns the last saved item with payload or an invalid item when save is
      * not called yet.
      */
-    Akonadi::Item item(ItemState state = AfterSave) const;
+    Q_REQUIRED_RESULT Akonadi::Item item(ItemState state = AfterSave) const;
 
     /**
      * Loads the @param item into the editor. The item passed must be
@@ -86,8 +74,8 @@ public:
     enum SaveAction {
         Create, /**< A new item was created */
         Modify, /**< An existing item was modified */
-        None,   /**< Nothing happened. */
-        Move,    /**< An existing item was moved to another collection */
+        None, /**< Nothing happened. */
+        Move, /**< An existing item was moved to another collection */
         MoveAndModify /**< An existing item was moved to another collection and modified */
     };
 
@@ -96,8 +84,7 @@ public:
 Q_SIGNALS:
     void itemSaveFinished(IncidenceEditorNG::EditorItemManager::SaveAction action);
 
-    void itemSaveFailed(IncidenceEditorNG::EditorItemManager::SaveAction action,
-                        const QString &message);
+    void itemSaveFailed(IncidenceEditorNG::EditorItemManager::SaveAction action, const QString &message);
 
     void revertFinished();
     void revertFailed(const QString &message);
@@ -110,13 +97,10 @@ private:
     Q_PRIVATE_SLOT(d_ptr, void itemChanged(const Akonadi::Item &, const QSet<QByteArray> &))
     Q_PRIVATE_SLOT(d_ptr, void itemFetchResult(KJob *))
     Q_PRIVATE_SLOT(d_ptr, void itemMoveResult(KJob *))
-    Q_PRIVATE_SLOT(d_ptr, void onModifyFinished(int changeId, const Akonadi::Item &item,
-                                                Akonadi::IncidenceChanger::ResultCode resultCode,
-                                                const QString &errorString))
-    Q_PRIVATE_SLOT(d_ptr, void onCreateFinished(int changeId,
-                                                const Akonadi::Item &item,
-                                                Akonadi::IncidenceChanger::ResultCode resultCode,
-                                                const QString &errorString))
+    Q_PRIVATE_SLOT(d_ptr,
+                   void onModifyFinished(int changeId, const Akonadi::Item &item, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorString))
+    Q_PRIVATE_SLOT(d_ptr,
+                   void onCreateFinished(int changeId, const Akonadi::Item &item, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorString))
     Q_PRIVATE_SLOT(d_ptr, void moveJobFinished(KJob *job))
 };
 
@@ -124,7 +108,7 @@ class ItemEditorUi
 {
 public:
     enum RejectReason {
-        ItemFetchFailed,      ///> Either the fetchjob failed or no items where returned
+        ItemFetchFailed, ///> Either the fetchjob failed or no items where returned
         ItemHasInvalidPayload, ///> The fetched item has an invalid payload
         ItemMoveFailed ///> Item move failed
     };
@@ -173,13 +157,13 @@ public:
     virtual Akonadi::Item save(const Akonadi::Item &item) = 0;
 
     /**
-     * Returns the currently sellected collection in which the item will be stored.
+     * Returns the currently selected collection in which the item will be stored.
      */
     virtual Akonadi::Collection selectedCollection() const = 0;
 
     /**
-     * This function is called if for some reason the creation or editting of the
-     * item cannot be continued. The implementing class must abort editting at
+     * This function is called if for some reason the creation or editing of the
+     * item cannot be continued. The implementing class must abort editing at
      * this point.
      */
     virtual void reject(RejectReason reason, const QString &errorMessage = QString()) = 0;
