@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (C) 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef INCIDENCEEDITOR_NG_H
@@ -23,9 +10,10 @@
 
 #include "incidenceeditor_export.h"
 
-#include <KCalCore/Incidence>
 #include <AkonadiCore/Item>
-namespace IncidenceEditorNG {
+#include <KCalendarCore/Incidence>
+namespace IncidenceEditorNG
+{
 /**
  * KCal Incidences are complicated objects. The user interfaces to create/modify
  * are therefore complex too. The IncedenceEditor class is a divide and conquer
@@ -42,14 +30,14 @@ public:
      * Load the values of @param incidence into the editor widgets. The passed
      * incidence is kept for comparing with the current values of the editor.
      */
-    virtual void load(const KCalCore::Incidence::Ptr &incidence) = 0;
+    virtual void load(const KCalendarCore::Incidence::Ptr &incidence) = 0;
     /// This was introduced to replace categories with Akonadi::Tags
     virtual void load(const Akonadi::Item &item);
 
     /**
-     * Store the current values of the editor into @param incidince.
+     * Store the current values of the editor into @param incidence .
      */
-    virtual void save(const KCalCore::Incidence::Ptr &incidence) = 0;
+    virtual void save(const KCalendarCore::Incidence::Ptr &incidence) = 0;
     /// This was introduced to replace categories with Akonadi::Tags
     virtual void save(Akonadi::Item &item);
 
@@ -79,11 +67,10 @@ public:
     /**
      * Returns the type of the Incidence that is currently loaded.
      */
-    Q_REQUIRED_RESULT KCalCore::IncidenceBase::IncidenceType type() const;
+    Q_REQUIRED_RESULT KCalendarCore::IncidenceBase::IncidenceType type() const;
 
     /** Convenience method to get a pointer for a specific const Incidence Type. */
-    template<typename IncidenceT>
-    QSharedPointer<IncidenceT> incidence() const
+    template<typename IncidenceT> QSharedPointer<IncidenceT> incidence() const
     {
         return mLoadedIncidence.dynamicCast<IncidenceT>();
     }
@@ -116,17 +103,16 @@ protected:
     /** Only subclasses can instantiate IncidenceEditors */
     IncidenceEditor(QObject *parent = nullptr);
 
-    template<typename IncidenceT>
-    QSharedPointer<IncidenceT> incidence(const KCalCore::Incidence::Ptr &inc)
+    template<typename IncidenceT> QSharedPointer<IncidenceT> incidence(const KCalendarCore::Incidence::Ptr &inc)
     {
         return inc.dynamicCast<IncidenceT>();
     }
 
 protected:
-    KCalCore::Incidence::Ptr mLoadedIncidence;
+    KCalendarCore::Incidence::Ptr mLoadedIncidence;
     mutable QString mLastErrorString;
-    bool mWasDirty;
-    bool mLoadingIncidence;
+    bool mWasDirty = false;
+    bool mLoadingIncidence = false;
 };
 } // IncidenceEditorNG
 
