@@ -39,10 +39,10 @@ Description of available recurrence types:
 
 enum {
     // Indexes of the month combo, keep in sync with descriptions.
-    ComboIndexMonthlyDay = 0,     // 11th of June
+    ComboIndexMonthlyDay = 0, // 11th of June
     ComboIndexMonthlyDayInverted, // 20th of June ( 11 to end )
-    ComboIndexMonthlyPos,         // 1st Monday of the Month
-    ComboIndexMonthlyPosInverted  // Last Monday of the Month
+    ComboIndexMonthlyPos, // 1st Monday of the Month
+    ComboIndexMonthlyPosInverted // Last Monday of the Month
 };
 
 enum {
@@ -70,27 +70,21 @@ IncidenceRecurrence::IncidenceRecurrence(IncidenceDateTime *dateTime, Ui::EventO
     handleEndAfterOccurrencesChange(1);
     toggleRecurrenceWidgets(RecurrenceTypeNone);
     fillCombos();
-    const QList<QLineEdit *> lineEdits { mUi->mExceptionDateEdit->lineEdit(), mUi->mRecurrenceEndDate->lineEdit()};
+    const QList<QLineEdit *> lineEdits{mUi->mExceptionDateEdit->lineEdit(), mUi->mRecurrenceEndDate->lineEdit()};
     for (QLineEdit *lineEdit : lineEdits) {
         if (lineEdit) {
             lineEdit->setClearButtonEnabled(false);
         }
     }
 
-    connect(mDateTime, &IncidenceDateTime::startDateTimeToggled, this,
-            &IncidenceRecurrence::handleDateTimeToggle);
+    connect(mDateTime, &IncidenceDateTime::startDateTimeToggled, this, &IncidenceRecurrence::handleDateTimeToggle);
 
-    connect(mDateTime, &IncidenceDateTime::startDateChanged, this,
-            &IncidenceRecurrence::handleStartDateChange);
+    connect(mDateTime, &IncidenceDateTime::startDateChanged, this, &IncidenceRecurrence::handleStartDateChange);
 
-    connect(mUi->mExceptionAddButton, &QPushButton::clicked, this,
-            &IncidenceRecurrence::addException);
-    connect(mUi->mExceptionRemoveButton, &QPushButton::clicked, this,
-            &IncidenceRecurrence::removeExceptions);
-    connect(mUi->mExceptionDateEdit, &KDateComboBox::dateChanged, this,
-            &IncidenceRecurrence::handleExceptionDateChange);
-    connect(mUi->mExceptionList, &QListWidget::itemSelectionChanged, this,
-            &IncidenceRecurrence::updateRemoveExceptionButton);
+    connect(mUi->mExceptionAddButton, &QPushButton::clicked, this, &IncidenceRecurrence::addException);
+    connect(mUi->mExceptionRemoveButton, &QPushButton::clicked, this, &IncidenceRecurrence::removeExceptions);
+    connect(mUi->mExceptionDateEdit, &KDateComboBox::dateChanged, this, &IncidenceRecurrence::handleExceptionDateChange);
+    connect(mUi->mExceptionList, &QListWidget::itemSelectionChanged, this, &IncidenceRecurrence::updateRemoveExceptionButton);
     connect(mUi->mRecurrenceTypeCombo, qOverload<int>(&QComboBox::currentIndexChanged), this, &IncidenceRecurrence::handleRecurrenceTypeChange);
     connect(mUi->mEndDurationEdit, qOverload<int>(&QSpinBox::valueChanged), this, &IncidenceRecurrence::handleEndAfterOccurrencesChange);
     connect(mUi->mFrequencyEdit, qOverload<int>(&QSpinBox::valueChanged), this, &IncidenceRecurrence::handleFrequencyChange);
@@ -99,29 +93,27 @@ IncidenceRecurrence::IncidenceRecurrence(IncidenceDateTime *dateTime, Ui::EventO
     connect(mUi->mRecurrenceTypeCombo, qOverload<int>(&QComboBox::currentIndexChanged), this, &IncidenceRecurrence::checkDirtyStatus);
     connect(mUi->mFrequencyEdit, qOverload<int>(&QSpinBox::valueChanged), this, &IncidenceRecurrence::checkDirtyStatus);
     connect(mUi->mFrequencyEdit, qOverload<int>(&QSpinBox::valueChanged), this, &IncidenceRecurrence::checkDirtyStatus);
-    connect(mUi->mWeekDayCombo, &IncidenceEditorNG::KWeekdayCheckCombo::checkedItemsChanged, this,
-            &IncidenceRecurrence::checkDirtyStatus);
+    connect(mUi->mWeekDayCombo, &IncidenceEditorNG::KWeekdayCheckCombo::checkedItemsChanged, this, &IncidenceRecurrence::checkDirtyStatus);
     connect(mUi->mMonthlyCombo, qOverload<int>(&QComboBox::currentIndexChanged), this, &IncidenceRecurrence::checkDirtyStatus);
     connect(mUi->mYearlyCombo, qOverload<int>(&QComboBox::currentIndexChanged), this, &IncidenceRecurrence::checkDirtyStatus);
     connect(mUi->mRecurrenceEndCombo, qOverload<int>(&QComboBox::currentIndexChanged), this, &IncidenceRecurrence::checkDirtyStatus);
     connect(mUi->mEndDurationEdit, qOverload<int>(&QSpinBox::valueChanged), this, &IncidenceRecurrence::checkDirtyStatus);
-    connect(mUi->mRecurrenceEndDate, &KDateComboBox::dateChanged, this,
-            &IncidenceRecurrence::checkDirtyStatus);
-    connect(mUi->mThisAndFutureCheck, &QCheckBox::stateChanged, this,
-            &IncidenceRecurrence::checkDirtyStatus);
+    connect(mUi->mRecurrenceEndDate, &KDateComboBox::dateChanged, this, &IncidenceRecurrence::checkDirtyStatus);
+    connect(mUi->mThisAndFutureCheck, &QCheckBox::stateChanged, this, &IncidenceRecurrence::checkDirtyStatus);
 }
 
 // this method must be at the top of this file in order to ensure
 // that its message to translators appears before any usages of this method.
 KLocalizedString IncidenceRecurrence::subsOrdinal(const KLocalizedString &text, int number) const
 {
-    QString q = i18nc("In several of the messages below, "
-                      "an ordinal number is substituted into the message. "
-                      "Translate this as \"0\" if English ordinal suffixes "
-                      "should be added (1st, 22nd, 123rd); "
-                      "translate this as \"1\" if just the number itself "
-                      "should be substituted (1, 22, 123).",
-                      "0");
+    QString q = i18nc(
+        "In several of the messages below, "
+        "an ordinal number is substituted into the message. "
+        "Translate this as \"0\" if English ordinal suffixes "
+        "should be added (1st, 22nd, 123rd); "
+        "translate this as \"1\" if just the number itself "
+        "should be substituted (1, 22, 123).",
+        "0");
     if (q == QLatin1Char('0')) {
         const QString ordinal = numberToString(number);
         return text.subs(ordinal);
@@ -142,11 +134,10 @@ void IncidenceRecurrence::load(const KCalendarCore::Incidence::Ptr &incidence)
     mCurrentDate = mLoadedIncidence->dateTime(KCalendarCore::IncidenceBase::RoleRecurrenceStart).date();
 
     mDateTime->load(incidence);
-    mDateTime->endDate();
     fillCombos();
     setDefaults();
 
-    //This is an exception
+    // This is an exception
     if (mLoadedIncidence->hasRecurrenceId()) {
         handleRecurrenceTypeChange(RecurrenceTypeException);
         mUi->mThisAndFutureCheck->setChecked(mLoadedIncidence->thisAndFuture());
@@ -171,8 +162,7 @@ void IncidenceRecurrence::load(const KCalendarCore::Incidence::Ptr &incidence)
         handleRecurrenceTypeChange(RecurrenceTypeDaily);
         setFrequency(f);
         break;
-    case KCalendarCore::Recurrence::rWeekly:
-    {
+    case KCalendarCore::Recurrence::rWeekly: {
         mUi->mRecurrenceTypeCombo->setCurrentIndex(RecurrenceTypeWeekly);
         handleRecurrenceTypeChange(RecurrenceTypeWeekly);
         QBitArray disableDays(7 /*size*/, false /*default value*/);
@@ -190,7 +180,7 @@ void IncidenceRecurrence::load(const KCalendarCore::Incidence::Ptr &incidence)
         setFrequency(f);
         break;
     case KCalendarCore::Recurrence::rYearlyMonth: // Fall through
-    case KCalendarCore::Recurrence::rYearlyPos:   // Fall through
+    case KCalendarCore::Recurrence::rYearlyPos: // Fall through
     case KCalendarCore::Recurrence::rYearlyDay:
         mUi->mRecurrenceTypeCombo->setCurrentIndex(RecurrenceTypeYearly);
         handleRecurrenceTypeChange(RecurrenceTypeYearly);
@@ -226,8 +216,7 @@ void IncidenceRecurrence::writeToIncidence(const KCalendarCore::Incidence::Ptr &
         return;
     }
 
-    if (recurrenceType == RecurrenceTypeNone
-        || !mUi->mRecurrenceTypeCombo->isEnabled()) {
+    if (recurrenceType == RecurrenceTypeNone || !mUi->mRecurrenceTypeCombo->isEnabled()) {
         return;
     }
 
@@ -261,19 +250,19 @@ void IncidenceRecurrence::writeToIncidence(const KCalendarCore::Incidence::Ptr &
         r->setYearly(mUi->mFrequencyEdit->value());
 
         if (mUi->mYearlyCombo->currentIndex() == ComboIndexYearlyMonth) {
-            //Every nth of month
+            // Every nth of month
             r->addYearlyDate(dayOfMonthFromStart());
             r->addYearlyMonth(currentDate().month());
         } else if (mUi->mYearlyCombo->currentIndex() == ComboIndexYearlyMonthInverted) {
-            //Every (last - n)th last day of month
+            // Every (last - n)th last day of month
             r->addYearlyDate(-dayOfMonthFromEnd());
             r->addYearlyMonth(currentDate().month());
         } else if (mUi->mYearlyCombo->currentIndex() == ComboIndexYearlyPos) {
-            //Every ith weekday of month
+            // Every ith weekday of month
             r->addYearlyMonth(currentDate().month());
             r->addYearlyPos(monthWeekFromStart(), weekday());
         } else if (mUi->mYearlyCombo->currentIndex() == ComboIndexYearlyPosInverted) {
-            //Every (last - i)th last weekday of month
+            // Every (last - i)th last weekday of month
             r->addYearlyMonth(currentDate().month());
             r->addYearlyPos(-monthWeekFromEnd(), weekday());
         } else {
@@ -300,8 +289,7 @@ void IncidenceRecurrence::save(const KCalendarCore::Incidence::Ptr &incidence)
 bool IncidenceRecurrence::isDirty() const
 {
     const RecurrenceType recurrenceType = currentRecurrenceType();
-    if (mLoadedIncidence->recurs()
-        && recurrenceType == RecurrenceTypeNone) {
+    if (mLoadedIncidence->recurs() && recurrenceType == RecurrenceTypeNone) {
         return true;
     }
 
@@ -322,50 +310,43 @@ bool IncidenceRecurrence::isDirty() const
     const KCalendarCore::Recurrence *recurrence = mLoadedIncidence->recurrence();
     switch (recurrence->recurrenceType()) {
     case KCalendarCore::Recurrence::rDaily:
-        if (recurrenceType != RecurrenceTypeDaily
-            || mUi->mFrequencyEdit->value() != recurrence->frequency()) {
+        if (recurrenceType != RecurrenceTypeDaily || mUi->mFrequencyEdit->value() != recurrence->frequency()) {
             return true;
         }
 
         break;
     case KCalendarCore::Recurrence::rWeekly:
-        if (recurrenceType != RecurrenceTypeWeekly
-            || mUi->mFrequencyEdit->value() != recurrence->frequency()
+        if (recurrenceType != RecurrenceTypeWeekly || mUi->mFrequencyEdit->value() != recurrence->frequency()
             || mUi->mWeekDayCombo->days() != recurrence->days()) {
             return true;
         }
         break;
     case KCalendarCore::Recurrence::rMonthlyDay:
-        if (recurrenceType != RecurrenceTypeMonthly
-            || mUi->mFrequencyEdit->value() != recurrence->frequency()
+        if (recurrenceType != RecurrenceTypeMonthly || mUi->mFrequencyEdit->value() != recurrence->frequency()
             || mUi->mMonthlyCombo->currentIndex() != mMonthlyInitialType) {
             return true;
         }
         break;
     case KCalendarCore::Recurrence::rMonthlyPos:
-        if (recurrenceType != RecurrenceTypeMonthly
-            || mUi->mFrequencyEdit->value() != recurrence->frequency()
+        if (recurrenceType != RecurrenceTypeMonthly || mUi->mFrequencyEdit->value() != recurrence->frequency()
             || mUi->mMonthlyCombo->currentIndex() != mMonthlyInitialType) {
             return true;
         }
         break;
     case KCalendarCore::Recurrence::rYearlyDay:
-        if (recurrenceType != RecurrenceTypeYearly
-            || mUi->mFrequencyEdit->value() != recurrence->frequency()
+        if (recurrenceType != RecurrenceTypeYearly || mUi->mFrequencyEdit->value() != recurrence->frequency()
             || mUi->mYearlyCombo->currentIndex() != mYearlyInitialType) {
             return true;
         }
         break;
     case KCalendarCore::Recurrence::rYearlyMonth:
-        if (recurrenceType != RecurrenceTypeYearly
-            || mUi->mFrequencyEdit->value() != recurrence->frequency()
+        if (recurrenceType != RecurrenceTypeYearly || mUi->mFrequencyEdit->value() != recurrence->frequency()
             || mUi->mYearlyCombo->currentIndex() != mYearlyInitialType) {
             return true;
         }
         break;
     case KCalendarCore::Recurrence::rYearlyPos:
-        if (recurrenceType != RecurrenceTypeYearly
-            || mUi->mFrequencyEdit->value() != recurrence->frequency()
+        if (recurrenceType != RecurrenceTypeYearly || mUi->mFrequencyEdit->value() != recurrence->frequency()
             || mUi->mYearlyCombo->currentIndex() != mYearlyInitialType) {
             return true;
         }
@@ -374,18 +355,15 @@ bool IncidenceRecurrence::isDirty() const
 
     // Recurrence end
     // -1 means "recurs forever"
-    if (recurrence->duration() == -1
-        && mUi->mRecurrenceEndCombo->currentIndex() != RecurrenceEndNever) {
+    if (recurrence->duration() == -1 && mUi->mRecurrenceEndCombo->currentIndex() != RecurrenceEndNever) {
         return true;
     } else if (recurrence->duration() == 0) {
         // 0 means "end date is set"
-        if (mUi->mRecurrenceEndCombo->currentIndex() != RecurrenceEndOn
-            || recurrence->endDate() != mUi->mRecurrenceEndDate->date()) {
+        if (mUi->mRecurrenceEndCombo->currentIndex() != RecurrenceEndOn || recurrence->endDate() != mUi->mRecurrenceEndDate->date()) {
             return true;
         }
     } else if (recurrence->duration() > 0) {
-        if (mUi->mEndDurationEdit->value() != recurrence->duration()
-            || mUi->mRecurrenceEndCombo->currentIndex() != RecurrenceEndAfter) {
+        if (mUi->mEndDurationEdit->value() != recurrence->duration() || mUi->mRecurrenceEndCombo->currentIndex() != RecurrenceEndAfter) {
             return true;
         }
     }
@@ -403,8 +381,7 @@ void IncidenceRecurrence::focusInvalidField()
     KCalendarCore::Incidence::Ptr incidence(mLoadedIncidence->clone());
     writeToIncidence(incidence);
     if (incidence->recurs()) {
-        if (mUi->mRecurrenceEndCombo->currentIndex() == RecurrenceEndOn
-            && !mUi->mRecurrenceEndDate->date().isValid()) {
+        if (mUi->mRecurrenceEndCombo->currentIndex() == RecurrenceEndOn && !mUi->mRecurrenceEndDate->date().isValid()) {
             mUi->mRecurrenceEndDate->setFocus();
         }
     }
@@ -414,7 +391,7 @@ bool IncidenceRecurrence::isValid() const
 {
     mLastErrorString.clear();
     if (currentRecurrenceType() == IncidenceEditorNG::RecurrenceTypeException) {
-        //Nothing you can do wrong here
+        // Nothing you can do wrong here
         return true;
     }
     KCalendarCore::Incidence::Ptr incidence(mLoadedIncidence->clone());
@@ -428,14 +405,14 @@ bool IncidenceRecurrence::isValid() const
     // Check if the incidence will occur at least once
     if (incidence->recurs()) {
         // dtStart for events, dtDue for to-dos
-        const QDateTime referenceDate
-            = incidence->dateTime(KCalendarCore::Incidence::RoleRecurrenceStart);
+        const QDateTime referenceDate = incidence->dateTime(KCalendarCore::Incidence::RoleRecurrenceStart);
 
         if (referenceDate.isValid()) {
             if (!(incidence->recurrence()->recursOn(referenceDate.date(), referenceDate.timeZone())
                   || incidence->recurrence()->getNextDateTime(referenceDate).isValid())) {
-                mLastErrorString = i18n("A recurring event or to-do must occur at least once. "
-                                        "Adjust the recurring parameters.");
+                mLastErrorString = i18n(
+                    "A recurring event or to-do must occur at least once. "
+                    "Adjust the recurring parameters.");
                 qCDebug(INCIDENCEEDITOR_LOG) << mLastErrorString;
                 return false;
             }
@@ -445,8 +422,7 @@ bool IncidenceRecurrence::isValid() const
             return false;
         }
 
-        if (mUi->mRecurrenceEndCombo->currentIndex() == RecurrenceEndOn
-            && !mUi->mRecurrenceEndDate->date().isValid()) {
+        if (mUi->mRecurrenceEndCombo->currentIndex() == RecurrenceEndOn && !mUi->mRecurrenceEndDate->date().isValid()) {
             mLastErrorString = i18nc("@info", "The recurrence end date is invalid.");
             qCDebug(INCIDENCEEDITOR_LOG) << mLastErrorString;
             return false;
@@ -490,27 +466,23 @@ void IncidenceRecurrence::fillCombos()
     mUi->mMonthlyCombo->clear();
     const QDate date = mDateTime->startDate();
 
-    QString item = subsOrdinal(
-        ki18nc("example: the 30th", "the %1"), dayOfMonthFromStart()).toString();
+    QString item = subsOrdinal(ki18nc("example: the 30th", "the %1"), dayOfMonthFromStart()).toString();
     mUi->mMonthlyCombo->addItem(item);
 
-    item = subsOrdinal(ki18nc("example: the 4th to last day",
-                              "the %1 to last day"), dayOfMonthFromEnd()).toString();
+    item = subsOrdinal(ki18nc("example: the 4th to last day", "the %1 to last day"), dayOfMonthFromEnd()).toString();
     mUi->mMonthlyCombo->addItem(item);
 
-    item = subsOrdinal(
-        ki18nc("example: the 5th Wednesday", "the %1 %2"), monthWeekFromStart()).
-           subs(QLocale::system().dayName(date.dayOfWeek(),
-                                          QLocale::QLocale::LongFormat)).toString();
+    item = subsOrdinal(ki18nc("example: the 5th Wednesday", "the %1 %2"), monthWeekFromStart())
+               .subs(QLocale::system().dayName(date.dayOfWeek(), QLocale::QLocale::LongFormat))
+               .toString();
     mUi->mMonthlyCombo->addItem(item);
 
     if (monthWeekFromEnd() == 1) {
-        item = ki18nc("example: the last Wednesday", "the last %1").
-               subs(QLocale::system().dayName(date.dayOfWeek(), QLocale::LongFormat)).toString();
+        item = ki18nc("example: the last Wednesday", "the last %1").subs(QLocale::system().dayName(date.dayOfWeek(), QLocale::LongFormat)).toString();
     } else {
-        item = subsOrdinal(
-            ki18nc("example: the 5th to last Wednesday", "the %1 to last %2"), monthWeekFromEnd()).
-               subs(QLocale::system().dayName(date.dayOfWeek(), QLocale::LongFormat)).toString();
+        item = subsOrdinal(ki18nc("example: the 5th to last Wednesday", "the %1 to last %2"), monthWeekFromEnd())
+                   .subs(QLocale::system().dayName(date.dayOfWeek(), QLocale::LongFormat))
+                   .toString();
     }
     mUi->mMonthlyCombo->addItem(item);
     mUi->mMonthlyCombo->setCurrentIndex(currentMonthlyIndex == -1 ? 0 : currentMonthlyIndex);
@@ -524,37 +496,32 @@ void IncidenceRecurrence::fillCombos()
     const int currentYearlyIndex = mUi->mYearlyCombo->currentIndex();
     mUi->mYearlyCombo->clear();
     const QString longMonthName = QLocale::system().monthName(date.month(), QLocale::LongFormat);
-    item = subsOrdinal(ki18nc("example: the 5th of June", "the %1 of %2"), date.day()).
-           subs(longMonthName).toString();
+    item = subsOrdinal(ki18nc("example: the 5th of June", "the %1 of %2"), date.day()).subs(longMonthName).toString();
     mUi->mYearlyCombo->addItem(item);
 
-    item = subsOrdinal(
-        ki18nc("example: the 3rd to last day of June", "the %1 to last day of %2"),
-        dayOfMonthFromEnd()).subs(longMonthName).toString();
+    item = subsOrdinal(ki18nc("example: the 3rd to last day of June", "the %1 to last day of %2"), dayOfMonthFromEnd()).subs(longMonthName).toString();
     mUi->mYearlyCombo->addItem(item);
 
-    item = subsOrdinal(
-        ki18nc("example: the 4th Wednesday of June", "the %1 %2 of %3"), monthWeekFromStart()).
-           subs(QLocale::system().dayName(date.dayOfWeek(), QLocale::LongFormat)).
-           subs(longMonthName).toString();
+    item = subsOrdinal(ki18nc("example: the 4th Wednesday of June", "the %1 %2 of %3"), monthWeekFromStart())
+               .subs(QLocale::system().dayName(date.dayOfWeek(), QLocale::LongFormat))
+               .subs(longMonthName)
+               .toString();
     mUi->mYearlyCombo->addItem(item);
 
     if (monthWeekFromEnd() == 1) {
-        item = ki18nc("example: the last Wednesday of June", "the last %1 of %2").
-               subs(QLocale::system().dayName(date.dayOfWeek(), QLocale::LongFormat)).
-               subs(longMonthName).toString();
+        item = ki18nc("example: the last Wednesday of June", "the last %1 of %2")
+                   .subs(QLocale::system().dayName(date.dayOfWeek(), QLocale::LongFormat))
+                   .subs(longMonthName)
+                   .toString();
     } else {
-        item = subsOrdinal(
-            ki18nc("example: the 4th to last Wednesday of June", "the %1 to last %2 of %3 "),
-            monthWeekFromEnd()).
-               subs(QLocale::system().dayName(date.dayOfWeek(), QLocale::LongFormat)).
-               subs(longMonthName).toString();
+        item = subsOrdinal(ki18nc("example: the 4th to last Wednesday of June", "the %1 to last %2 of %3 "), monthWeekFromEnd())
+                   .subs(QLocale::system().dayName(date.dayOfWeek(), QLocale::LongFormat))
+                   .subs(longMonthName)
+                   .toString();
     }
     mUi->mYearlyCombo->addItem(item);
 
-    item = subsOrdinal(
-        ki18nc("example: the 15th day of the year", "the %1 day of the year"),
-        date.dayOfYear()).toString();
+    item = subsOrdinal(ki18nc("example: the 15th day of the year", "the %1 day of the year"), date.dayOfYear()).toString();
     mUi->mYearlyCombo->addItem(item);
     mUi->mYearlyCombo->setCurrentIndex(currentYearlyIndex == -1 ? 0 : currentYearlyIndex);
 }
@@ -569,8 +536,7 @@ void IncidenceRecurrence::handleDateTimeToggle()
 
 void IncidenceRecurrence::handleEndAfterOccurrencesChange(int currentValue)
 {
-    mUi->mRecurrenceOccurrencesLabel->setText(
-        i18ncp("Recurrence ends after n occurrences", "occurrence", "occurrences", currentValue));
+    mUi->mRecurrenceOccurrencesLabel->setText(i18ncp("Recurrence ends after n occurrences", "occurrence", "occurrences", currentValue));
 }
 
 void IncidenceRecurrence::handleExceptionDateChange(const QDate &currentDate)
@@ -578,9 +544,7 @@ void IncidenceRecurrence::handleExceptionDateChange(const QDate &currentDate)
     const QDate date = mUi->mExceptionDateEdit->date();
     const QString dateStr = QLocale().toString(date);
 
-    mUi->mExceptionAddButton->setEnabled(
-        currentDate >= mDateTime->startDate()
-        && mUi->mExceptionList->findItems(dateStr, Qt::MatchExactly).isEmpty());
+    mUi->mExceptionAddButton->setEnabled(currentDate >= mDateTime->startDate() && mUi->mExceptionList->findItems(dateStr, Qt::MatchExactly).isEmpty());
 }
 
 void IncidenceRecurrence::handleFrequencyChange()
@@ -612,11 +576,15 @@ void IncidenceRecurrence::handleRecurrenceTypeChange(int currentIndex)
         freqKey = QLatin1Char('d');
     }
 
-    const QString labelEvery = ki18ncp("repeat >every< N years/months/...; "
-                                       "dynamic context 'type': 'd' days, 'w' weeks, "
-                                       "'m' months, 'y' years",
-                                       "every", "every").
-                               subs(frequency).inContext(QStringLiteral("type"), freqKey).toString();
+    const QString labelEvery = ki18ncp(
+                                   "repeat >every< N years/months/...; "
+                                   "dynamic context 'type': 'd' days, 'w' weeks, "
+                                   "'m' months, 'y' years",
+                                   "every",
+                                   "every")
+                                   .subs(frequency)
+                                   .inContext(QStringLiteral("type"), freqKey)
+                                   .toString();
     mUi->mFrequencyLabel->setText(labelEvery);
     mUi->mRecurrenceRuleLabel->setText(labelFreq);
 
@@ -697,7 +665,7 @@ short IncidenceRecurrence::monthWeekFromStart() const
         count = 1;
         QDate tmp = date.addDays(-7);
         while (tmp.month() == date.month()) {
-            tmp = tmp.addDays(-7);   // Count backward
+            tmp = tmp.addDays(-7); // Count backward
             ++count;
         }
     } else {
@@ -717,7 +685,7 @@ short IncidenceRecurrence::monthWeekFromEnd() const
         count = 1;
         QDate tmp = date.addDays(7);
         while (tmp.month() == date.month()) {
-            tmp = tmp.addDays(7);    // Count forward
+            tmp = tmp.addDays(7); // Count forward
             ++count;
         }
     } else {
@@ -734,12 +702,16 @@ QString IncidenceRecurrence::numberToString(int number) const
     // The code in here was adapted from an article by Johnathan Wood, see:
     // http://www.blackbeltcoder.com/Articles/strings/converting-numbers-to-ordinal-strings
 
-    static QString _numSuffixes[] = {
-        QStringLiteral("th"), QStringLiteral("st"), QStringLiteral("nd"), QStringLiteral("rd"),
-        QStringLiteral("th"), QStringLiteral("th"), QStringLiteral("th"), QStringLiteral("th"),
-        QStringLiteral(
-            "th"), QStringLiteral("th")
-    };
+    static QString _numSuffixes[] = {QStringLiteral("th"),
+                                     QStringLiteral("st"),
+                                     QStringLiteral("nd"),
+                                     QStringLiteral("rd"),
+                                     QStringLiteral("th"),
+                                     QStringLiteral("th"),
+                                     QStringLiteral("th"),
+                                     QStringLiteral("th"),
+                                     QStringLiteral("th"),
+                                     QStringLiteral("th")};
 
     int i = (number % 100);
     int j = (i > 10 && i < 20) ? 0 : (number % 10);
@@ -748,8 +720,7 @@ QString IncidenceRecurrence::numberToString(int number) const
 
 void IncidenceRecurrence::selectMonthlyItem(KCalendarCore::Recurrence *recurrence, ushort recurenceType)
 {
-    Q_ASSERT(recurenceType == KCalendarCore::Recurrence::rMonthlyPos
-             || recurenceType == KCalendarCore::Recurrence::rMonthlyDay);
+    Q_ASSERT(recurenceType == KCalendarCore::Recurrence::rMonthlyPos || recurenceType == KCalendarCore::Recurrence::rMonthlyDay);
 
     if (recurenceType == KCalendarCore::Recurrence::rMonthlyPos) {
         QList<KCalendarCore::RecurrenceRule::WDayPos> rmp = recurrence->monthPositions();
@@ -757,7 +728,7 @@ void IncidenceRecurrence::selectMonthlyItem(KCalendarCore::Recurrence *recurrenc
             return; // Use the default values. Probably marks the editor as dirty
         }
 
-        if (rmp.first().pos() > 0) {   // nth day
+        if (rmp.first().pos() > 0) { // nth day
             // TODO if ( rmp.first().pos() != mDateTime->startDate().day() ) { warn user }
             // NOTE: This silently changes the recurrence when:
             //       rmp.first().pos() != mDateTime->startDate().day()
@@ -772,8 +743,7 @@ void IncidenceRecurrence::selectMonthlyItem(KCalendarCore::Recurrence *recurrenc
     } else { // Monthly by day
         // check if we have any setting for which day (vcs import is broken and
         // does not set any day, thus we need to check)
-        const int day = recurrence->monthDays().isEmpty() ? currentDate().day()
-                        : recurrence->monthDays().at(0);
+        const int day = recurrence->monthDays().isEmpty() ? currentDate().day() : recurrence->monthDays().at(0);
 
         // Days from the end are after the ones from the begin, so correct for the
         // negative sign and add 30 (index starting at 0)
@@ -791,8 +761,7 @@ void IncidenceRecurrence::selectMonthlyItem(KCalendarCore::Recurrence *recurrenc
 
 void IncidenceRecurrence::selectYearlyItem(KCalendarCore::Recurrence *recurrence, ushort recurenceType)
 {
-    Q_ASSERT(recurenceType == KCalendarCore::Recurrence::rYearlyDay
-             || recurenceType == KCalendarCore::Recurrence::rYearlyMonth
+    Q_ASSERT(recurenceType == KCalendarCore::Recurrence::rYearlyDay || recurenceType == KCalendarCore::Recurrence::rYearlyMonth
              || recurenceType == KCalendarCore::Recurrence::rYearlyPos);
 
     if (recurenceType == KCalendarCore::Recurrence::rYearlyDay) {
@@ -803,8 +772,7 @@ void IncidenceRecurrence::selectYearlyItem(KCalendarCore::Recurrence *recurrence
         // TODO Check if day has actually the same value as in the combo.
         mUi->mYearlyCombo->setCurrentIndex(ComboIndexYearlyDay);
     } else if (recurenceType == KCalendarCore::Recurrence::rYearlyMonth) {
-        const int day = recurrence->yearDates().isEmpty() ? currentDate().day()
-                        : recurrence->yearDates().at(0);
+        const int day = recurrence->yearDates().isEmpty() ? currentDate().day() : recurrence->yearDates().at(0);
 
         /*
         int month = currentDate().month();
@@ -820,7 +788,7 @@ void IncidenceRecurrence::selectYearlyItem(KCalendarCore::Recurrence *recurrence
         } else {
             mUi->mYearlyCombo->setCurrentIndex(ComboIndexYearlyMonthInverted);
         }
-    } else { //KCalendarCore::Recurrence::rYearlyPos
+    } else { // KCalendarCore::Recurrence::rYearlyPos
         /*
         int month = currentDate().month();
         if ( !recurrence->yearMonths().isEmpty() ) {
@@ -866,13 +834,13 @@ void IncidenceRecurrence::setDefaults()
 
     mUi->mWeekDayCombo->setDays(checkDays, disableDays);
 
-    mUi->mMonthlyCombo->setCurrentIndex(0);   // Recur on the nth of the month
-    mUi->mYearlyCombo->setCurrentIndex(0);    // Recur on the nth of the month
+    mUi->mMonthlyCombo->setCurrentIndex(0); // Recur on the nth of the month
+    mUi->mYearlyCombo->setCurrentIndex(0); // Recur on the nth of the month
 }
 
 void IncidenceRecurrence::setDuration(int duration)
 {
-    if (duration == -1) {   // No end date
+    if (duration == -1) { // No end date
         mUi->mRecurrenceEndCombo->setCurrentIndex(RecurrenceEndNever);
         mUi->mRecurrenceEndStack->setCurrentIndex(0);
     } else if (duration == 0) {
@@ -907,8 +875,7 @@ void IncidenceRecurrence::setFrequency(int frequency)
 
 void IncidenceRecurrence::toggleRecurrenceWidgets(int recurrenceType)
 {
-    bool enable = (recurrenceType != RecurrenceTypeNone)
-                  && (recurrenceType != RecurrenceTypeException);
+    bool enable = (recurrenceType != RecurrenceTypeNone) && (recurrenceType != RecurrenceTypeException);
     mUi->mRecurrenceTypeCombo->setVisible(recurrenceType != RecurrenceTypeException);
     mUi->mRepeatLabel->setVisible(recurrenceType != RecurrenceTypeException);
     mUi->mRecurrenceEndLabel->setVisible(enable);
@@ -975,8 +942,7 @@ RecurrenceType IncidenceRecurrence::currentRecurrenceType() const
     }
 
     const int currentIndex = mUi->mRecurrenceTypeCombo->currentIndex();
-    Q_ASSERT_X(currentIndex >= 0 && currentIndex < RecurrenceTypeUnknown, "currentRecurrenceType",
-               "Keep the combo-box values in sync with the enum");
+    Q_ASSERT_X(currentIndex >= 0 && currentIndex < RecurrenceTypeUnknown, "currentRecurrenceType", "Keep the combo-box values in sync with the enum");
     return static_cast<RecurrenceType>(currentIndex);
 }
 
