@@ -17,20 +17,26 @@ class KGuiItem;
 
 class TestIndividualMailDialog;
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 // Shows a dialog with a question and the option to select which attendee should get the mail or to open a composer for him.
 // Used to get individual mails for attendees of an event.
 class IndividualMailDialog : public QDialog
 {
     Q_OBJECT
     friend class ::TestIndividualMailDialog;
+
 public:
     enum Decisions {
-        Update,         /**< send automatic mail to attendee */
-        NoUpdate,       /**< do not send mail to attendee */
-        Edit            /**< open composer for attendee */
+        Update, /**< send automatic mail to attendee */
+        NoUpdate, /**< do not send mail to attendee */
+        Edit /**< open composer for attendee */
     };
-    explicit IndividualMailDialog(const QString &question, const KCalendarCore::Attendee::List &attendees, const KGuiItem &buttonYes, const KGuiItem &buttonNo, QWidget *parent = nullptr);
+    explicit IndividualMailDialog(const QString &question,
+                                  const KCalendarCore::Attendee::List &attendees,
+                                  const KGuiItem &buttonYes,
+                                  const KGuiItem &buttonNo,
+                                  QWidget *parent = nullptr);
     ~IndividualMailDialog() override;
 
     Q_REQUIRED_RESULT KCalendarCore::Attendee::List editAttendees() const;
@@ -39,7 +45,7 @@ public:
 private:
     void updateButtonState();
 
-    std::vector<std::pair<KCalendarCore::Attendee, QComboBox *> > mAttendeeDecision;
+    std::vector<std::pair<KCalendarCore::Attendee, QComboBox *>> mAttendeeDecision;
     QDialogButtonBox *m_buttons = nullptr;
     QWidget *m_detailsWidget = nullptr;
 };
