@@ -13,7 +13,8 @@
 #include <QComboBox>
 #include <QTimeZone>
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 /**
  * A combobox that shows the system timezones available in QTimeZone
  * and provides methods to easily select the item corresponding to a given
@@ -34,7 +35,7 @@ public:
     /**
      * Destroys the time zone combobox.
      */
-    ~KTimeZoneComboBox();
+    ~KTimeZoneComboBox() override;
 
     /**
      * Selects the item in the combobox corresponding to the given @p zone.
