@@ -12,14 +12,20 @@
 #include <KIdentityManagement/Identity>
 #include <KJob>
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 // Opens a Composer with a mail with one attachment (constructed my ITIPHandler)
 class OpenComposerJob : public KJob
 {
     Q_OBJECT
 
 public:
-    explicit OpenComposerJob(QObject *parent, const QString &to, const QString &cc, const QString &bcc, const KMime::Message::Ptr &message, const KIdentityManagement::Identity &identity);
+    explicit OpenComposerJob(QObject *parent,
+                             const QString &to,
+                             const QString &cc,
+                             const QString &bcc,
+                             const KMime::Message::Ptr &message,
+                             const KIdentityManagement::Identity &identity);
     ~OpenComposerJob() override;
 
     void start() override;
