@@ -16,7 +16,8 @@
 #include <QModelIndex>
 #include <QSet>
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 class ResourceModel : public QAbstractItemModel
 {
     Q_OBJECT
@@ -25,10 +26,7 @@ public:
     /* Copied from https://doc.qt.io/qt-5/qtwidgets-itemviews-editabletreemodel-example.html:
      * Editable Tree Model Example
      */
-    enum Roles {
-        Resource = Qt::UserRole,
-        FullName
-    };
+    enum Roles { Resource = Qt::UserRole, FullName };
 
     explicit ResourceModel(const QStringList &headers, QObject *parent = nullptr);
     ~ResourceModel() override;
@@ -45,19 +43,19 @@ public:
     Q_REQUIRED_RESULT Qt::ItemFlags flags(const QModelIndex &index) const override;
 
     Q_REQUIRED_RESULT bool removeRows(int position, int rows, const QModelIndex &parent = QModelIndex()) override;
+
 private:
     ResourceItem *getItem(const QModelIndex &index) const;
 
-    ResourceItem::Ptr rootItem;
+    ResourceItem::Ptr mRootItem;
 
 public:
-
     /* Start search on LDAP Server with the given string.
      * If the model is not ready to search, the string is cached and is executed afterwards.
      */
     void startSearch(const QString &);
-private:
 
+private:
     /* Start search with cached string (stored in searchString)
      *
      */
@@ -66,38 +64,38 @@ private:
     /* Search for collections of resources
      *
      */
-    KLDAP::LdapClientSearch ldapSearchCollections;
+    KLDAP::LdapClientSearch *mLdapSearchCollections = nullptr;
 
     /* Search for matching resources
      *
      */
-    KLDAP::LdapClientSearch ldapSearch;
+    KLDAP::LdapClientSearch *mLdapSearch = nullptr;
 
     /* Map from dn of resource -> collectionItem
      * A Resource can be part of different collection, so a QMuliMap is needed
      *
      */
-    QMultiMap<QString, ResourceItem::Ptr> ldapCollectionsMap;
+    QMultiMap<QString, ResourceItem::Ptr> mLdapCollectionsMap;
 
     /* A Set of all collection ResourceItems
      *
      */
-    QSet <ResourceItem::Ptr> ldapCollections;
+    QSet<ResourceItem::Ptr> mLdapCollections;
 
     /* Cached searchString (set by startSearch(QString))
      *
      */
-    QString searchString;
+    QString mSearchString;
 
     /* Is the search of collections ended
      *
      */
-    bool foundCollection = false;
+    bool mFoundCollection = false;
 
     /* List of all attributes in LDAP an the headers of the model
      *
      */
-    QStringList headers;
+    QStringList mHeaders;
 
 private:
     /* Slot for founded collections
